@@ -88,16 +88,12 @@ r <- attributes(result)
 # We populated min/mean/dl
 ok(ut_cmp_identical(
     r$stock_a__minlen,
-    array(
-        c(10),
-        dimnames = list("10:Inf"),
-        dim = c(1))), "stock_a__minlen")
+    c("10:Inf" = 10)), "stock_a__minlen")
 ok(ut_cmp_identical(
     r$stock_a__midlen,
-    array(
+    structure(
         c(10.5),
-        dimnames = list("10:Inf"),
-        dim = c(1))), "stock_a__midlen")
+        names = c("10:Inf"))), "stock_a__midlen")
 ok(ut_cmp_identical(r$stock_a__minmidlen, 10.5), "stock_a__minmidlen")
 ok(ut_cmp_identical(r$stock_a__maxmidlen, 10.5), "stock_a__maxmidlen")
 ok(ut_cmp_identical(
@@ -108,16 +104,14 @@ ok(ut_cmp_identical(
     1), "stock_a__plusdl")
 ok(ut_cmp_identical(
     r$stock_b__minlen,
-    array(
+    structure(
         c(50, 51, 52, 53, 54),
-        dimnames = list(c("50:51", "51:52", "52:53", "53:54", "54:Inf")),
-        dim = c(5))), "stock_b__minlen")
+        names = c("50:51", "51:52", "52:53", "53:54", "54:Inf"))), "stock_b__minlen")
 ok(ut_cmp_identical(
     r$stock_b__midlen,
-    array(
+    structure(
         c(50.5, 51.5, 52.5, 53.5, 54.5),
-        dimnames = list(c("50:51", "51:52", "52:53", "53:54", "54:Inf")),
-        dim = c(5))), "stock_b__midlen")
+        names = c("50:51", "51:52", "52:53", "53:54", "54:Inf"))), "stock_b__midlen")
 ok(ut_cmp_identical(r$stock_b__minmidlen, 50.5), "stock_b__minmidlen")
 ok(ut_cmp_identical(r$stock_b__maxmidlen, 54.5), "stock_b__maxmidlen")
 ok(ut_cmp_identical(
@@ -128,16 +122,14 @@ ok(ut_cmp_identical(
     1), "stock_b__plusdl")
 ok(ut_cmp_identical(
     r$stock_wonky__minlen,
-    array(
+    structure(
         c(0, 10, 100, 200, 1000),
-        dimnames = list(c("0:10", "10:100", "100:200", "200:1000", "1000:Inf")),
-        dim = c(5))), "stock_wonky__minlen")
+        names = c("0:10", "10:100", "100:200", "200:1000", "1000:Inf"))), "stock_wonky__minlen")
 ok(ut_cmp_equal(
     r$stock_wonky__midlen,
-    array(
+    structure(
         c(5, 55, 150, 600, 1005),
-        dimnames = list(c("0:10", "10:100", "100:200", "200:1000", "1000:Inf")),
-        dim = c(5))), "stock_wonky__midlen")
+        names = c("0:10", "10:100", "100:200", "200:1000", "1000:Inf"))), "stock_wonky__midlen")
 ok(ut_cmp_identical(r$stock_wonky__minmidlen, 5), "stock_wonky__minmidlen")
 ok(ut_cmp_identical(r$stock_wonky__maxmidlen, 1005), "stock_wonky__maxmidlen")
 ok(ut_cmp_equal(
